@@ -1,6 +1,6 @@
 package FvwmPiazza::Layouts::Grid;
 {
-  $FvwmPiazza::Layouts::Grid::VERSION = '0.3';
+  $FvwmPiazza::Layouts::Grid::VERSION = '0.3001';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ FvwmPiazza::Layouts::Grid - Grid layout.
 
 =head1 VERSION
 
-version 0.3
+version 0.3001
 
 =head1 SYNOPSIS
 
@@ -84,14 +84,17 @@ sub apply_layout {
     my $height_ratio;
 
     # new-style
-    my $parser = new Getopt::Long::Parser();
-    if (!$parser->getoptionsfromarray(\@options,
-                                      "cols=n" => \$num_cols,
-                                      'ratios=s@' => \@rat_args,
-                                      "width_ratio=s" => \$width_ratio,
-                                      "height_ratio=s" => \$height_ratio))
     {
-        $args{tiler}->debug("Grid failed to parse options: " . join(':', @options));
+        local @ARGV = @options;
+        my $parser = new Getopt::Long::Parser();
+        if (!$parser->getoptions("cols=n" => \$num_cols,
+                                 'ratios=s@' => \@rat_args,
+                                 "width_ratio=s" => \$width_ratio,
+                                 "height_ratio=s" => \$height_ratio))
+        {
+            $args{tiler}->debug("Grid failed to parse options: " . join(':', @ARGV));
+        }
+        @options = @ARGV;
     }
     if (@rat_args)
     {
@@ -144,6 +147,7 @@ sub apply_layout {
     }
 
     my $num_rows = int($max_win / $num_cols);
+    $args{tiler}->debug("Grid max_win=$max_win, num_cols=$num_cols, num_rows=$num_rows\n");
 
     # Calculate the width and height ratios
     my @width_ratios =
@@ -176,7 +180,8 @@ sub apply_layout {
 	    $row_height = int($working_height * $height_ratios[$row_nr]);
 	}
 
-	my $group = $area->group($gnr);
+        $args{tiler}->debug("Grid xpos=$xpos, ypos=$ypos, col_width=$col_width, row_height=$row_height\n");
+        my $group = $area->group($gnr);
 	$group->arrange_group(module=>$args{tiler},
 	    x=>$xpos,
 	    y=>$ypos,
