@@ -1,6 +1,6 @@
 package FvwmPiazza::Layouts::Rows;
 {
-  $FvwmPiazza::Layouts::Rows::VERSION = '0.3';
+  $FvwmPiazza::Layouts::Rows::VERSION = '0.3001';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ FvwmPiazza::Layouts::Rows - Rows layout.
 
 =head1 VERSION
 
-version 0.3
+version 0.3001
 
 =head1 SYNOPSIS
 
@@ -79,11 +79,14 @@ sub apply_layout {
     # parse the options, if any
     my @options = @{$args{options}};
     my $ratio_args;
-    my $parser = new Getopt::Long::Parser();
-    if (!$parser->getoptionsfromarray(\@options,
-                                      'ratios=s' => \$ratio_args))
     {
-        $args{tiler}->debug("Grid failed to parse options: " . join(':', @options));
+        local @ARGV = @options;
+        my $parser = new Getopt::Long::Parser();
+        if (!$parser->getoptions('ratios=s' => \$ratio_args))
+        {
+            $args{tiler}->debug("Grid failed to parse options: " . join(':', @options));
+        }
+        @options = @ARGV;
     }
     if (!defined $ratio_args)
     {
