@@ -1,6 +1,6 @@
 package FvwmPiazza::Layouts::Wide;
 {
-  $FvwmPiazza::Layouts::Wide::VERSION = '0.3';
+  $FvwmPiazza::Layouts::Wide::VERSION = '0.3001';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ FvwmPiazza::Layouts::Wide - Wide layout.
 
 =head1 VERSION
 
-version 0.3
+version 0.3001
 
 =head1 SYNOPSIS
 
@@ -84,15 +84,18 @@ sub apply_layout {
     my $width_ratio;
     my $height_ratio;
 
-    # new-style
-    my $parser = new Getopt::Long::Parser();
-    if (!$parser->getoptionsfromarray(\@options,
-                                      'variant=s' => \$wide_style,
-                                      'ratios=s@' => \@rat_args,
-                                      "width_ratio=s" => \$width_ratio,
-                                      "height_ratio=s" => \$height_ratio))
     {
-        $args{tiler}->debug("Failed to parse options: " . join(':', @options));
+        local @ARGV = @options;
+        my $parser = new Getopt::Long::Parser();
+        if (!$parser->getoptions(
+                'variant=s' => \$wide_style,
+                'ratios=s@' => \@rat_args,
+                "width_ratio=s" => \$width_ratio,
+                "height_ratio=s" => \$height_ratio))
+        {
+            $args{tiler}->debug("Failed to parse options: " . join(':', @options));
+        }
+        @options = @ARGV;
     }
     if (@rat_args)
     {
